clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read and process friction data and compute data points for flow curves 

% Version: 11-7-2022
% Matlab version: R2021a


%% initialisation
figure(1), clf(1)
figure(2), clf(2)
figure(3), clf(3)
mat_type = 2; % 1: C/PEEK, 2: C/LM-PAEK
ss_first = 4.5; % mm/min, threshold, steady state evaluated at first part of curve (not at end)
mod_coeff = 0.90; %threshold for modulus fit, end; max difference local and average modulus
rel_time = 28.5; % time after sliding stopped for relaxation curve

if mat_type == 1 % C/PEEK material
    serie_range = [2 3 15]; % series of experiments (relates to unique number of specimen)
    series{1} = [8 7 6 1 2 3 4 5 9 10 11]; % experiments in series/range (relates to unique number of specimen)
    series{2} = [12 11 10 9 8 7 1 6 5 2 4];
    series{3} = [7 8 9 10 11 12 13 14 15 16 17 18];
elseif mat_type == 2 % C/LM-PAEK material
    serie_range = [17]; % series of experiments (relates to unique number of specimen)
    series{1} = [1 2 3 13 14 15 4 5 6 16 17 7 8 9 21 18 22 19 10 11 12 20 25 26 27 28 29 30 31 32 33 34 35 36]; % experiments in range (relates to unique number of specimen)
end

%% Go through the measurements

V_mean_vec = []; % store values in loop; mean velocity
tau_peak_vec = []; % store values in loop; peak shear stress (tau_p)
tau_mean_vec = []; % store values in loop; long-time shear stress (tau_infty)
d_tau_end_vec = []; % store values in loop; residual stress (tau_y)

for serie_i = 1:length(serie_range) % go through series (of experiments)
    
    serie = serie_range(serie_i);
    range_meas = series{serie_i};
    
    for meas_i = 1:length(range_meas) % go through measurements within specific series

        meas = range_meas(meas_i);

        %% Load data
        if mat_type == 1
            cd ../FT_C-PEEK_15kPa_385degC
        elseif mat_type == 2
            cd ../FT_C-LMPAEK_15kPA_365degC
        end
        file_find = dir(['*_',num2str(serie),'-',num2str(meas),'.*']);
        file_name = file_find.name;
        
        if file_name(end-2:end) == 'txt'  % data logged on laptop (different format, higher sampling rate)
            data = readmatrix(file_name,'NumHeaderLines',1);
            fprintf(['File: ', file_find.name,'\n'])
            cd ../Scripts
            
            t = data(:,1); % time [s]
            d = data(:,6) - data(1,6);  % displacement [mm]
            force_corr = mean(data(end-200:end,5)); % end value (end of experiment)
            f_pull = data(:,5) - force_corr; % pull force, corrected for end value [N}
            
        else    % data logged on friction tester PC (lower sampling rate)
            fid = fopen(file_name);
            C = textscan(fid,'%f');
            data = zeros(int32(length(C{1})/13),13);
            for i = 0:length(C{1})-1
                i_row = 1+floor(i/13);
                i_col = 1+mod(i,13);
                data(int32(i_row),int32(i_col)) = C{1}(i+1);
            end
            fprintf(['File: ', file_find.name,'\n'])
            fclose(fid);
            cd ../Scripts
            
            t = data(:,2) - data(1,2); % time [s]
            d = data(1,13) - data(:,13); % displacement [mm]
            force_corr = mean(data(end-5:end,6)); % end value (end of experiment)
            f_pull = data(:,6) - force_corr; % pull force, corrected for end value [N]
            
        end       
        
        %% Analysis

        %% index start/end using displacement data, mean velocity, shear stress
        
        % velocity from file name
        name_u = find(file_find.name=='u');
        name_u_end = name_u + 1;
        while file_find.name(name_u_end) ~= '_'
            name_u_end = name_u_end + 1;
        end
        vel = str2double(file_find.name(name_u+1:name_u_end-1)); % velocity from file name

        % determine window for smoothening based on velocity form file name
        if file_name(end-2:end) == 'txt'  % data logged on laptop (higher sampling rate; larger window for smoothening)
            if vel <= 1
                window = 525;
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 100;
            elseif vel <= 11
                window = 40;
            elseif vel <= 15
                window = 20;
            elseif vel <= 30
                window = 20;
            else
                window = 15;
            end
        else
            if vel <= 1
                window = 100;
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 50;
            elseif vel <= 8
                window = 25;
            elseif vel <= 15
                window = 15;
            else
                window = 15;
            end
        end

        % smoothing data
        d_filt = smoothdata(d,'gaussian',window); % filter data

        v_vec = [0]; % velocity vector
        a_vec = [0]; % acceleration vector
        for i = 2:length(t)-1
            dt = t(i+1) - t(i);
            v = (d_filt(i+1)-d_filt(i-1))/(2*dt);
            a = (d_filt(i+1)-2*d_filt(i)+d_filt(i-1))/(dt^2);
            v_vec(i) = v;
            a_vec(i) = a;
        end
        v_vec(length(t)) = v;
        a_vec(length(t)) = a;
        
        % determine global start and end of friction response
        i_glob = 1; % global end range of start point
        while d(i_glob) < 1 % deformation below 1 mm
            i_glob = i_glob + 1;
        end
        
        i_glob_9 = i_glob; % global end range of start point, also global start range for end point
        while d(i_glob_9) < 9 % deformation around 9 mm
            i_glob_9 = i_glob_9 + 1;
        end
        
        i_glob_start = i_glob; % find around i_glob also global start range for start point
        while t(i_glob_start) > t(i_glob)-(2/vel*60)  % move 2 mm in time earlier based on velocity in experiment
            i_glob_start = i_glob_start - 1;
        end
                
        i_glob_end = i_glob;
        if mat_type == 1
            while t(i_glob_end) < t(i_glob) + d(end)/vel*60 % find index for time after full displacement
                i_glob_end = i_glob_end + 1;
            end
        else
            while t(i_glob_end) < t(i_glob) + min(11.5,max(d))/vel*60 % find index for time after 11.5 mm displacement (not d(end) because of additional movement after testing...)
                i_glob_end = i_glob_end + 1;
            end           
        end           
                
        idx_start = find(a_vec(i_glob_start:i_glob)==max(a_vec(i_glob_start:i_glob)))+i_glob_start-1;
        idx_end = find(a_vec(i_glob_9:i_glob_end)==min(a_vec(i_glob_9:i_glob_end)))+i_glob_9-1;

        % mean velocity
        V_mean = (d(idx_end)-d(idx_start))/(t(idx_end)-t(idx_start)); % mm/s
        V_mean_vec = [V_mean_vec, V_mean];
        
        % shear stress
        tau = f_pull/2500/2*1e3; % [N/mm] -> MPa, times 1e3 results in [kPa] (division by 2, as 2 slip interfaces are present)
        
        % determine range for mean shear stress
        if vel <= ss_first  % evaluate tau_mean in first part of the curve, as a small but gradual increase is seen with time at low velocity (perhaps due to the longer test times involved)
            t_ss_first = t(idx_start) + 1/vel*60;  %start after 1 mm 
            ss_idx_start = idx_start;
            while t(ss_idx_start) < t_ss_first
                ss_idx_start = ss_idx_start + 1;
            end
            t_ss_end_first = t_ss_first + 1*60/vel;    %end after another 1 mm extra
            ss_idx_end = ss_idx_start;
            while t(ss_idx_end) < t_ss_end_first
                ss_idx_end = ss_idx_end + 1;
            end
            tau_mean = mean(tau(ss_idx_start:ss_idx_end));
                        
        else  % steady state region at end of measurement
            ss_end = min(d(idx_end),10);  % max 10 mm slip length
            ss_start = ss_end - 2;  % 2 mm steady state region (~start at 8 mm)

            ss_idx_start = idx_start;
            while d(ss_idx_start) < ss_start
                ss_idx_start = ss_idx_start + 1;
            end
            ss_idx_end = ss_idx_start;
            while d(ss_idx_end) < ss_end
                ss_idx_end = ss_idx_end + 1;
            end
            tau_mean = mean(tau(ss_idx_start:ss_idx_end));
        end
        
        % determine peak index
        idx_peak = find(tau(idx_start:ss_idx_end)==max(tau(idx_start:ss_idx_end)))+idx_start-1;
        idx_peak = min(idx_peak); % in case multiple valaues at same stress level: pick first one
        
        % store shear stress characteristics of friction response (tau_p and tau_infty)
        tau_peak_vec = [tau_peak_vec, tau(idx_peak)];
        tau_mean_vec = [tau_mean_vec, tau_mean];
                
        %% Relaxation
        % used to obtain end value after full relaxation (yield stress)
        
        % start and end indices
        idx_f_rel_start = idx_end - 10; % global start range for point of relaxation start
        idx_f_rel_end = idx_end + 10;   % global end range for point of relaxation start
        
        % determine derivative to identify start of relaxation (drop in
        % shear stress)
        dtau_dt_sec_vec = [];
        for i_rel = idx_f_rel_start:idx_f_rel_end
            dt = mean([t(i_rel+1)-t(i_rel),t(i_rel)-t(i_rel-1)]);  % avg dt within stencils for derivative of shear stress wrt time
            dtau_dt_sec = (tau(i_rel+1)-2*tau(i_rel)+tau(i_rel-1))/(dt^2); % compute derivative
            dtau_dt_sec_vec = [dtau_dt_sec_vec, dtau_dt_sec]; % store
        end
        
        idx_rel_start = find(dtau_dt_sec_vec==min(dtau_dt_sec_vec))+idx_f_rel_start-2; % minus 1: to obtain correct pos, extra minus 1: to start before actual sharp decrease
        
        % find end of relaxation
        idx_rel_end = idx_rel_start;
        while t(idx_rel_end) < t(idx_rel_start)+rel_time  
            idx_rel_end = idx_rel_end + 1;
        end
        tau_rel = tau(idx_rel_start:idx_rel_end);
        t_rel = t(idx_rel_start:idx_rel_end)-t(idx_rel_start); 
        d_tau_end = mean(tau_rel(end-10:end)); % end value of shear stress after ~full relaxation
        
        % store residual stress (tau_y)
        d_tau_end_vec = [d_tau_end_vec, d_tau_end];
          
        %% modulus fit
        % used to correct data
        
        [t,d] = mod_fit_v1(idx_start,idx_end,t,d,tau,mod_coeff,window);
        
        %% Show data

        % friction response
        figure(2), hold on
        plot(d,f_pull,'-k')
        plot(d(idx_peak),f_pull(idx_peak),'xg','markersize',15);
        plot(d(ss_idx_start),f_pull(ss_idx_start),'xr','markersize',15);
        plot(d(ss_idx_end),f_pull(ss_idx_end),'xb','markersize',15);
        xlabel('Displacement [mm]')
        ylabel('Pull force [N]')
        box on
        grid on   

        % relaxation
        figure(3), hold on
        plot(t_rel,tau_rel,'-k')
        xlabel('Recovery time [s]','interpreter','latex','fontsize',14)
        ylabel('Shear stress [kPa]','interpreter','latex','fontsize',14)
        box on
        grid on

    end
end


%% Outside of the loop

figure(2), legend('Friction data','Peak','Start steady-state','End steady-state')

% flow curve with characteristics of friction response
figure(1), hold on
i_store = 1;
for serie_i = 1:length(serie_range)
    
    serie = serie_range(serie_i);
    range_meas = series{serie_i};
    
    for i_meas = 1:length(range_meas)
        plt = plot(V_mean_vec(i_store),tau_peak_vec(i_store)-d_tau_end_vec(i_store),'^','color','black','markersize',6); %,'displayname',['Meas: ',num2str(serie),'-', num2str(range_meas(i_meas))]
        set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
        plt = plot(V_mean_vec(i_store),tau_mean_vec(i_store)-d_tau_end_vec(i_store),'o','color','black','markersize',6); %,'displayname',['Meas: ',num2str(serie),'-', num2str(range_meas(i_meas))]
        set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
        i_store = i_store + 1;
    end
end

% legend
plot(1e3,1e3,'^','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,p}}$'])
plot(1e3,9e2,'o','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,\infty}}$'])

xlabel('Velocity, $V$ [mm/s]','interpreter','Latex','fontsize',18)
ylabel('Shear stress (matrix), $\tau_{\rm{mat}}$ [kPa]','interpreter','Latex','fontsize',18)
box on
grid on
legend('location','SouthEast','interpreter','latex','fontsize',16,'box','off')
axis([1e-2 5 1 175])
set(gca,'XScale','log','YScale','log','fontsize',18)


%% Store data points

%save('data_points','V_mean_vec','tau_mean_vec','tau_peak_vec','d_tau_end_vec');

