clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Run certain height profile with 1D shear rate approach to determine
% average shear stress with velocity to compare with measured friction data
% (characteristics; peak and long-time shear stresses)

% Matlab version: R2021a


%% initialisation

V_vec = logspace(0,2.25,10)/60; % mm/s

% viscosity parameters PEEK, 385 degC
eta_0_Cross = 589; % Pas
tau_0_Cross = 5.987e4; 
n_Cross = 0.39;

figure(1), clf(1)

%% Load data

% show data points (from saved data)
figure(1), hold on 
cd ../Flow_curve_data
load('data_points_T_C-PEEK_pp_385_15.mat');
cd ../Scripts

plot(V_mean_vec,tau_mean_vec-d_tau_end_vec,'o','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,p}}$']); 
plot(V_mean_vec,tau_peak_vec-d_tau_end_vec,'^','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,\infty}}$']); 

%% Load and analysis on height profiles

% Height profiles generated using ImageJ and Matlab analysis 
specimen_labels = ["2_3_1_R_zoom", "2_3_2_L_zoom", "2_3_2_R_zoom", "2_3_3_R_zoom", "2_3_3_R_zoom_2", "2_6_1_R_zoom", "2_6_2_R_zoom", "2_6_3_R_zoom"];
nr_specimens = length(specimen_labels);

% unsmoothed data
profiles = [];
for i = 1:nr_specimens
    specimen_i_UI = "profile_" + specimen_labels(i) + "_UI_7.mat";
    specimen_i_LI = "profile_" + specimen_labels(i) + "_LI_7.mat";
    profiles = [profiles, specimen_i_UI, specimen_i_LI];
end

tau_store = []; % store values from profiles to obtain mean and sample std

% range of profiles
for k = 1:length(profiles)
    cd ../Profiles
    load(profiles(k));
    cd ../Scripts

    x_profile = global_x*1e3; % widht direction, in mm
    y_profile = global_y*1e3; % height (thickness) direction, in mm
    
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,0,V_vec);
    tau_store = [tau_store; tau_avg_vec*1e-3]; % store vector avg shear stress with rate for each profile, in kPa
    
end

% compute mean profile response and sample standard deviation
tau_mean = mean(tau_store);
tau_std = std(tau_store);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'-k','color',[0.5 0.5 0.5],'linewidth',1.0,'displayname',['$\bar{\tau}_{\rm{avg}}$, micrographs,' newline 'unsmooth'])

% smoothed data (same procedure)
profiles = [];
for i = 1:nr_specimens
    specimen_i_UI_circ = "profile_" + specimen_labels(i) + "_UI_7_circ3.5.mat";
    specimen_i_LI_circ = "profile_" + specimen_labels(i) + "_LI_7_circ3.5.mat";
    profiles = [profiles, specimen_i_UI_circ, specimen_i_LI_circ];
end

tau_store = []; % store values from profiles to obtain mean and std

% range of profiles
for k = 1:length(profiles)
    cd ../Profiles
    load(profiles(k));
    cd ../Scripts

    x_profile = global_x*1e3; % widht direction, in mm
    y_profile = global_y*1e3; % height (thickness) direction, in mm
       
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,0,V_vec);
    tau_store = [tau_store; tau_avg_vec*1e-3]; % store vector avg shear stress with rate for each profile, in kPa
    
end

% compute mean profile response and sample standard deviation
tau_mean = mean(tau_store);
tau_std = std(tau_store);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'-k','linewidth',1.0,'displayname',['$\bar{\tau}_{\rm{avg}}$, micrographs,' newline 'smoothed'])


% smoothed data + slip (same procedure, but now local viscous shear stress bounded by critical shear stress)
tau_cr = 35e3; % critical shear stress for strong slip
tau_store = []; % store values from profiles to obtain mean and std

% range of profiles
for k = 1:length(profiles)
    cd ../Profiles
    load(profiles(k));
    cd ../Scripts

    x_profile = global_x*1e3; % widht direction, in mm
    y_profile = global_y*1e3; % height (thickness) direction, in mm
    
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,tau_cr,V_vec);
    tau_store = [tau_store; tau_avg_vec*1e-3]; % store vector avg shear stress with rate for each profile, in kPa
    
end

% compute mean profile response and sample standard deviation
tau_mean = mean(tau_store);
tau_std = std(tau_store);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'--k','linewidth',1.0,'displayname',['$\bar{\tau}_{\rm{avg,slip}}$, micrographs,' newline 'smoothed'])
plt = plot([1.5 5],[tau_cr*1e-3 tau_cr*1e-3],'--k','color',[0.5 0.5 0.5],'linewidth',1.0);
set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
text(3.4,41.0,'$\tau_{\rm{c,2}}$','color',[0.5 0.5 0.5]','interpreter','latex','fontsize',10)

ylabel('Shear stress, $\tau$ [kPa]','interpreter','Latex','fontsize',10)
xlabel('Rate, $V$ [mm/s]','interpreter','Latex','fontsize',10)
legend('location','SouthEast','interpreter','latex','box','off','fontsize',10)
set(gca,'XScale','log','YScale','log','fontsize',10)

% figure size 
width = 14; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([1e-2 5 1 175])
grid on
box on