clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Run certain height profile with 1D shear rate approach to determine
% average shear stress with velocity to compare with measured friction data

% Matlab version: R2021a


%% initialisation
V_vec = logspace(0,2.25,10)/60; % sliding velocity, mm/s

% viscosity parameters PEEK (385 degC)
eta_0_Cross = 589; 
tau_0_Cross = 5.987e4; 
n_Cross = 0.39;

figure(1), clf(1)

%% Load data

% show data points (from saved data)
figure(1), hold on 
cd ../Flow_curve_data
load('data_points_T_C-PEEK_pp_385_15.mat');
cd ../Scripts

plot(V_mean_vec,tau_mean_vec-d_tau_end_vec,'o','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,p}}$']); 
plot(V_mean_vec,tau_peak_vec-d_tau_end_vec,'^','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,\infty}}$']); 

%% Load and analysis on height profiles

% Height profiles generated using Matlab analysis on generated fiber
% distribution from Melro et al's algorithm
profile = "profile_gen_dist_59_multiple.mat";

cd ../Profiles
load(profile);
cd ../Scripts

tau_store = []; % store values from profiles to obtain mean and std
tau_store_slip = []; % store values from profiles with slip effect
tau_cr = 35e3; % critical shear stress for onset of slip, in kPa

for k = 1:length(store_profile)
    
    x_profile = store_profile{k}(1,:)*1e3; % width direction, in mm
    y_profile = store_profile{k}(2,:)*1e3; % height (thickness) direction, in mm
    
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,0,V_vec);
    tau_avg_vec_slip = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,tau_cr,V_vec);
    tau_store = [tau_store; tau_avg_vec*1e-3]; % store vector avg shear stress with rate for each profile, in kPa
    tau_store_slip = [tau_store_slip; tau_avg_vec_slip*1e-3]; % store vector avg shear stress with rate for each profile, in kPa
    
end

% compute mean profile response and sample standard deviation
tau_mean = mean(tau_store);
tau_std = std(tau_store);
tau_mean_slip = mean(tau_store_slip);
tau_std_slip = std(tau_store_slip);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'-k','linewidth',1.0,'displayname',['$\bar{\tau}_{\rm{avg}}$, gen. distr.'])
errorbar(V_vec,tau_mean_slip,tau_std_slip,'--k','linewidth',1.0,'displayname',['$\bar{\tau}_{\rm{avg,slip}}$, gen. distr.'])

ylabel('Shear stress, $\tau$ [kPa]','interpreter','Latex','fontsize',10)
xlabel('Rate, $V$ [mm/s]','interpreter','Latex','fontsize',10)
legend('location','SouthEast','interpreter','latex','box','off','fontsize',10)
set(gca,'XScale','log','YScale','log','fontsize',10)

% figure size 
width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([1e-2 5 1 125])
grid on
box on