clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Run certain height profile (from micrographs and from generated fiber
% distributions using the algorithm of Melro et al) with 1D shear rate 
% approach to determine the average shear stress with velocity to compare 
% with the measured friction data on C/LM-PAEK 

% Matlab version: R2021a


%% initialisation
V_vec = logspace(0,2.25,10)/60; % sliding velocity, mm/s

% viscosity parameters LM-PAEK (365 degC)
eta_0_Cross = 483; 
tau_0_Cross = 242597; 
n_Cross = 0.45;

figure(1), clf(1)

%% Load data

% show data points (from saved data))
figure(1), hold on 
cd ../Flow_curve_data
load('data_points_T_C-LMPAEK_pp_365_15.mat');
cd ../Scripts

plot(V_mean_vec,tau_mean_vec-d_tau_end_vec,'o','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,p}}$']); 
plot(V_mean_vec,tau_peak_vec-d_tau_end_vec,'^','color','black','markerfacecolor','none','markersize',6,'displayname',['$\tau_{\rm{mat,\infty}}$']); 

%% Load and analysis on height profiles

% Height profiles generated using ImageJ and Matlab analysis (Read_process_ROI_data)
specimen_labels = ["17_5_1_L", "17_5_1_M", "17_5_1_R", "17_5_2_L", "17_5_2_M", "17_5_2_R", "17_5_3_L", "17_5_3_M", "17_5_3_R"];
nr_specimens = length(specimen_labels);

% smoothed data
profiles = [];
for i = 1:nr_specimens
    specimen_i_UI_circ = "profile_" + specimen_labels(i) + "_UI_7_circ3.5.mat";
    specimen_i_LI_circ = "profile_" + specimen_labels(i) + "_LI_7_circ3.5.mat";
    profiles = [profiles, specimen_i_UI_circ, specimen_i_LI_circ];
end

tau_store = []; % store values from profiles to obtain mean and std

% range of profiles
for k = 1:length(profiles)
    cd ../Profiles
    load(profiles(k));
    cd ../Scripts

    x_profile = global_x*1e3; 
    y_profile = global_y*1e3; 
    
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,0,V_vec);   
    tau_store = [tau_store; tau_avg_vec*1e-3];
    
end

% compute mean profile response and std
tau_mean = mean(tau_store);
tau_std = std(tau_store);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'-k','color',[0.6 0.6 0.6],'linewidth',1.0,'displayname','$\bar{\tau}_{\rm{avg}}$, micrographs')

% Height profiles from Matlab analysis on generated fiber distribution
profile = "profile_gen_dist_59_multiple.mat";

cd ../Profiles
load(profile);
cd ../Scripts

tau_store = []; % store values from profiles to obtain mean and std
tau_store_slip = []; % store values from profiles with slip
tau_cr = 55e3; % critical shear stress for onset of slip, in kPa

for k = 1:length(store_profile)
    
    x_profile = store_profile{k}(1,:)*1e3; 
    y_profile = store_profile{k}(2,:)*1e3; 
    
    % compute shear flow through profile for all rates
    tau_avg_vec = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,0,V_vec);
    tau_avg_vec_slip = compute_shear_flow(x_profile,y_profile,eta_0_Cross,tau_0_Cross,n_Cross,tau_cr,V_vec);
    tau_store = [tau_store; tau_avg_vec*1e-3];
    tau_store_slip = [tau_store_slip; tau_avg_vec_slip*1e-3];
    
end

% compute mean profile response and std
tau_mean = mean(tau_store);
tau_std = std(tau_store);
tau_mean_slip = mean(tau_store_slip);
tau_std_slip = std(tau_store_slip);

figure(1), hold on
errorbar(V_vec,tau_mean,tau_std,'-k','linewidth',1.0,'displayname','$\bar{\tau}_{\rm{avg}}$, gen. distr.')
errorbar(V_vec,tau_mean_slip,tau_std_slip,'--k','linewidth',1.0,'displayname','$\bar{\tau}_{\rm{avg,slip}}$, gen. distr.')

plt = plot([1.5 5],[tau_cr*1e-3 tau_cr*1e-3],'--k','color',[0.5 0.5 0.5],'linewidth',1.0);
set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
text(3.4,65,'$\tau_{\rm{c,2}}$','color',[0.5 0.5 0.5]','interpreter','latex','fontsize',10)

ylabel('Shear stress, $\tau$ [kPa]','interpreter','Latex','fontsize',10)
xlabel('Rate, $V$ [mm/s]','interpreter','Latex','fontsize',10)
legend('location','SouthEast','interpreter','latex','box','off','fontsize',10)
set(gca,'XScale','log','YScale','log','fontsize',10)

% figure size 
width = 14; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([1e-2 5 1 175])
grid on
box on