clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read and process LM-PAEK powder plate-plate rheometry experiments and
% fit data with Cross model, shown together with capillary data from Victrex

% Version: 2-12-2020
% Matlab version: R2021a

%% Initialisation

% plate-plate measurement 
ang_freq = [0.1000 0.1610 0.2590 0.4160 0.6690 1.0800 1.7300 2.7800 4.4700...
    7.1900 11.6000 18.6000 29.9000 48.1000 77.3000 124.0000 200.0000]; % in [rad/s]
com_visc = [486.7100 482.3100 477.3200 470.5800 464.5400 461.5400 458.4600...
    454.9900 450.1800 442.8700 432.6000 418.6800 399.7300 379.5500 355.2300...
    328.8900 301.4400]; % complex viscosity, Pas

% determined shear rate and viscosity from Victrex/Toray (capillary data)
shear_rate = [100 200 500 1e3 2e3 5e3 10e3]; % 1/s
visc_360 = [240 220 200 175 150 105 72]; % Pas (read from graph), 360 degC
visc_380 = [190 175 156 141 121 89 65]; % Pas (read from graph), 380 degC
visc_365 = zeros(1,length(visc_360));

figure(1), clf(1)

%% Plot viscosity from Victrex/Toray and plate-plate measurement at 365 degC

% interpolate Victrex data between 360 and 380 for data at 365 degC
for i = 1:length(visc_365)
    visc_365(i) = interp1([360 380],[visc_360(i) visc_380(i)],365);
end

figure(1), hold on
plot(ang_freq,com_visc,'-k^','linewidth',0.5,'markersize',6,'displayname',['Plate-plate meas.'])
plot(shear_rate,visc_365,'kx','markersize',6,'displayname',['Capillary data'])
   
%% Cross-WLF fit

% model fit
eta_cross = @(eta_0,tau_0,n,gam_dot) (eta_0)./(1+(eta_0.*gam_dot./tau_0).^(1-n)); % Cross model
[A, fvalA] = fminsearch(@(a) norm(eta_cross(a(1),a(2),a(3),ang_freq)-com_visc),[2550,1e5,0.62]);
eta_A = A(1);
tau_A = A(2);
n_A = A(3);
gam_plot = logspace(-2,4,100); % shear rate vector to plot Cross model fit

% plot results
plot(gam_plot,eta_cross(eta_A,tau_A,n_A,gam_plot),'-k','linewidth',2.0,'displayname',['Cross model fit' newline '$\eta_0$ = ', num2str(eta_A,'%0.f'),', $\tau^*$ = ', num2str(tau_A,'%0.f'), ', $n$ = ', num2str(n_A,'%0.2f')])

%% Figure options

yticks([50 100 500])
box on
grid on
legend('location','southwest','interpreter','latex','fontsize',10,'box','off')
xlabel('Shear rate, $\dot{\gamma}$ [1/s]','interpreter','latex','fontsize',10)
ylabel('Viscosity, $\eta$ [Pas]','interpreter','latex','fontsize',10)
set(gca,'XScale','log','YScale','log','fontsize',10)

% figure size 
width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([0.4 1e4 50 500])
grid on
box on
