clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read ROI (region of interest) file from ImageJ:
% - Load XY fiber (center) locations (txt output from ImageJ) and manually
%   set corner points of cross-section
% - Determine 1/3 and 2/3 lines (representing upper and lower interfaces)
% - Compute local matrix interlayer thickness above and below one of
%   interfaces by searching for fiber locations
% - Compute height profile, optionally apply soomthening, and optionally save result

% 15-7-2021: first version
% Matlab version: 2021a

%% Initialisation
df = 7;  % fiber diameter in micron
circ_fill = 1; % 1: smoothening; fill valleys with arches
R_c_0 = 3.5; % radius circle in micron (used to search for connection points for smoothing (horizontal distance))
l_max = 20;  % maximum radius to fill valley (in case large vertical distance; large distance between points)

% no fiber input (vertical measurement line in micrograph)
x_left = 886;
x_right = 896;

% lower and upper corner points (y-axis)
y_t_left = 696; 
y_t_right = 699; 
y_b_left = 92; 
y_b_right = 97; 

% pixel vs length scale
y_t_meas = 694;
y_b_meas = 94; 
meas_length = 435; 
pixel_micron = meas_length/(y_t_meas-y_b_meas);
dx = pixel_micron; 

figure(1), clf(1)

%% load txt file (and optionally .jpg micrograph)

cd ../Microscopy_data

file_name = '2_3_3_R_zoom_ROI_fmax.txt';  % ROI data based on smoothing + find maxima
data = readmatrix(file_name);
x = data(:,1);
y = max(data(:,2))-data(:,2); % flip data

figure(1), hold on
plt = plot(x*pixel_micron,y*pixel_micron,'k.','markersize',8,'color',[0.7 0.7 0.7]);
set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );

% show micrograph (.jpg)
figure(2), hold on
file_name = '2_3_3_R_zoom.jpg';  % micrograph image
fig = imread(file_name);
imshow(fig)
axis on
axis ij
hold on
plot(data(:,1),data(:,2),'r.','markersize',8)

cd ../Scripts

%% analyse height profile based on straight line

% top and bottom lines (in pixels)
y_top = @(x) y_t_left + ((y_t_right-y_t_left)/max(x))*x;
y_bot = @(x) y_b_left + ((y_b_right-y_b_left)/max(x))*x;

% compute lines at 1/3 and 2/3 of height -> assumed ply-ply interfaces
x_vec = 0:max(x)-1;
y_t_vec = y_top(x_vec);
y_b_vec = y_bot(x_vec);
y_i_u = y_t_vec - (y_t_vec-y_b_vec)/3; % y values for upper interface
y_i_l = y_b_vec + (y_t_vec-y_b_vec)/3; % y values for lower interface

%% compute vertical distance for each x value along the 1/3 and 2/3 lines (upper and lower interface)

% sort XY fiber coordinates
[x_sort,i_sort]=sort(x); % sort x and return ordering indices
y_sort = y(i_sort); % order y according to x

% values top and bottom (w.r.t base line)
y_top_vec = zeros(1,length(x_vec));  % values above base line, in micron
y_bot_vec = zeros(1,length(x_vec));  % values below base line, in micron 
x_profile = x_vec*pixel_micron;

% base line (lower or upper interface)
%y_base = y_i_u*pixel_micron; % middel of assumed upper interface, in micron; base line for computation matrix interlayer thickness
y_base = y_i_l*pixel_micron; % middle of assumed lower interface, in micron; base line for computation matrix interlayer thickness

% upper interface, go trough x vector
for i = 0:length(x_vec)-1  %note: start with zero because of pixel data; in micron data: i+1
    
    % range (depends on fiber diameter)
    range = floor((df/2)/pixel_micron);
    
    % local index (min range to plus range around point i)
    i_local = max(i-range,0); 
    
    % save y values for local_i (start with maximum values)
    y_top_local_dist_vec = [y_t_vec(i+1)*pixel_micron-y_base(i+1)];
    y_bot_local_dist_vec = [y_b_vec(i+1)*pixel_micron-y_base(i+1)];
    
    % go through i_local values (neighboring point for point i, add to local top and bottom y vectors
    while i_local <= i+range && i_local <= length(x_vec)-1
        y_val = y_sort(find(x_sort==i_local))*pixel_micron-y_base(i+1); % find y values on i_local point in micron
        y_bot_dist = max(y_val(y_val<0))+sqrt((0.5*df)^2-(dx*(i-i_local))^2); % find closests distance from base with fiber diameter taking into acount (w.r.t. to point i)
        y_top_dist = min(y_val(y_val>=0))-sqrt((0.5*df)^2-(dx*(i-i_local))^2);

        y_top_local_dist_vec = [y_top_local_dist_vec, y_top_dist]; % save distance for each local_i
        y_bot_local_dist_vec = [y_bot_local_dist_vec, y_bot_dist];    
        
        i_local = i_local + 1;
    end
    
    y_top_vec(i+1) = min(y_top_local_dist_vec); % save smallest distance w.r.t. base line
    y_bot_vec(i+1) = max(y_bot_local_dist_vec); % save smallest distance w.r.t. base line
end

% plot
figure(1), hold on
plot(x_profile,y_base,'-k','linewidth',2.0,'displayname','Baseline')
plot(x_profile,y_top_vec+y_base,'-k','linewidth',1.0,'displayname','Fiber edges')
plt = plot(x_profile,y_bot_vec+y_base,'-k','linewidth',1.0);
set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );

%% Determine height profile

% compute height difference
y_profile = y_top_vec - y_bot_vec;
idx_neg = find(y_profile<0); % find negative values; then fiber contact so zero 
y_profile(idx_neg) = 0;

% remove part with vertical measurement line (no fiber input)
if x_left ~= 0
    y_left = y_profile(x_left);
    y_right = y_profile(x_right);
    idx = x_left;
    while idx < x_right
        y_profile(idx) = y_left+(idx-x_left)*((y_right-y_left)/(x_right-x_left));
        idx = idx + 1;
    end
end

%% adjust profile: fill large gaps with circular shape

% - Find points with sharp decay/increase => valleys
% - For points with sharp decay or increase: find points in neighborhood with
%   opposite slope within 2*R_c horizontal distance
% - If point found: draw circle between two points with line acting as  
%   chord (if distance larger than 2*R_c, then increase R_c 
%   sufficiently (up to l_max; then skip))
% - Replace heigth vector with points on circle in case old points are 
%   further away from base line

if circ_fill == 1
    i_LR = []; % indices with interesting points, left to right
    i_RL = []; % indices with interesting points, right to left

    for i = 1:length(x_profile)-1

        % local slope
        dy = (y_bot_vec(i+1)+y_base(i+1)) - (y_bot_vec(i)+y_base(i));
        dx = x_profile(i+1) - x_profile(i);
        alpha = atan(dy/dx);
        % check slopes; if large decay/increase: possible to fill
        if alpha < -(67.5*pi/180) 
            i_LR = [i_LR, i]; % save index, from left to right
        elseif alpha > (67.5*pi/180) 
            i_RL = [i_RL, i+1];
        end
    end

    idx_neg = find(i_RL<=min(i_LR));
    i_RL(idx_neg) = [];
    idx_neg = find(i_LR>=max(i_RL));
    i_LR(idx_neg) = [];

    % x values for interesting pionts
    x_LR = x_profile(i_LR);
    x_RL = x_profile(i_RL);
    x_RL_prev = 0;

    % use local indices to draw circles
    for i = 1:length(i_LR)

        x_LR_i = x_LR(i);

        if x_LR_i > x_RL_prev

            %figure(1), hold on
            %plot(x_LR_i,y_bot_vec(i_LR(i))+y_base(i_LR(i)),'b.','markersize',14)

            % find points in neighborhood (from RL)
            R_c = R_c_0;
            i_neigh = find(x_RL>x_LR_i & x_RL<=x_LR_i+2*R_c);
            trig = 0;
            j = length(i_neigh);
            skip = 0;

            while trig == 0 && j >= 1

                R_c = R_c_0; 

                % point in from RL side
                x_RL_i = x_RL(i_neigh(j));
                %plot(x_RL_i,y_bot_vec(i_RL(i_neigh(j)))+y_base(i_RL(i_neigh(j))),'m.','markersize',14)

                % try to draw circle between points; first find suitable points
                dx = x_RL_i - x_LR_i;
                dy = y_bot_vec(i_RL(i_neigh(j)))+y_base(i_RL(i_neigh(j)))-(y_bot_vec(i_LR(i))+y_base(i_LR(i)));
                l = sqrt(dx^2+dy^2);
                if l > 2*R_c
                    R_c = l/2;
                end
                alpha = atan(dy/dx);
                beta = acos(.5*l/R_c);
                gamma = 0.5*pi-beta-alpha;
                x_m = x_LR_i+sin(gamma)*R_c;
                y_m = y_bot_vec(i_LR(i))+y_base(i_LR(i))+cos(gamma)*R_c;
                %plot(x_m,y_m,'k.','markersize',14)
                %x_circ = R_c*cos(0:0.1:2*pi);
                %y_circ = R_c*sin(0:0.1:2*pi);
                %plot(x_circ+x_m,y_circ+y_m,'-k')
                i_local = i_LR(i)+1;
                x_local = x_profile(i_local);
                y_new = []; % save y values

                while x_local < x_RL_i && x_local < x_profile(end)
                    y_new = [y_new, y_m - sqrt(R_c^2-(x_local-x_m)^2)-y_base(i_local)]; % new value for y_bot_vec

                    if y_new < y_bot_vec(i_local) % no correcting filling, stop -> possibly go to next point (j)
                        y_new = [];
                        x_local = x_RL_i;
                        j = j -1;
                    else
                        i_local = i_local +1;
                        x_local = x_profile(i_local);
                    end

                end

                if length(y_new) >= 1
                    y_bot_vec(i_LR(i)+1:i_local-1) = y_new;
                    idx_trig = i_RL(i_neigh(j));
                    x_RL_prev = x_RL_i;  % for next round: not trying to fill circles in range used earlier
                    trig = 1;

                    %plot(x_profile(i_LR(i)+1:i_local-1),y_new+y_base(i_LR(i)+1:i_local-1),'g.','markersize',12)
                end
            end
        end
    end

    % top surface
    i_LR = []; % indices with interesting points, left to right
    i_RL = []; % indices with interesting points, right to left

    for i = 1:length(x_profile)-1

        % local slope
        dy = (y_top_vec(i+1)+y_base(i+1)) - (y_top_vec(i)+y_base(i));
        dx = x_profile(i+1) - x_profile(i);
        alpha = atan(dy/dx);
        % check slopes; if large decay/increase: possible to fill
        if alpha > (67.5*pi/180) 
            i_LR = [i_LR, i]; % save index, from left to rigth
        elseif alpha < -(67.5*pi/180) 
            i_RL = [i_RL, i+1];
        end
    end

    idx_neg = find(i_RL<=min(i_LR));
    i_RL(idx_neg) = [];
    idx_neg = find(i_LR>=max(i_RL));
    i_LR(idx_neg) = [];

    % x values for interesting points
    x_LR = x_profile(i_LR);
    x_RL = x_profile(i_RL);
    x_RL_prev = 0;

    % use local indices to draw circles
    for i = 1:length(i_LR)

        x_LR_i = x_LR(i);

        if x_LR_i > x_RL_prev

            %figure(1), hold on
            %plot(x_LR_i,y_top_vec(i_LR(i))+y_base(i_LR(i)),'b.','markersize',14)

            % find points in neighborhood (from RL)
            R_c = R_c_0;
            i_neigh = find(x_RL>x_LR_i & x_RL<=x_LR_i+2*R_c);
            trig = 0;
            j = length(i_neigh);
            skip = 0;

            while trig == 0 && j >= 1

                R_c = R_c_0; 

                % point in from RL side
                x_RL_i = x_RL(i_neigh(j));
                %plot(x_RL_i,y_top_vec(i_RL(i_neigh(j)))+y_base(i_RL(i_neigh(j))),'m.','markersize',14)

                % try to draw circle between points; first find suitable points
                dx = x_RL_i - x_LR_i;
                dy = y_top_vec(i_RL(i_neigh(j)))+y_base(i_RL(i_neigh(j)))-(y_top_vec(i_LR(i))+y_base(i_LR(i)));
                l = sqrt(dx^2+dy^2);
                if l > 2*R_c
                    R_c = l/2;
                end
                alpha = atan(dy/dx);
                beta = acos(.5*l/R_c);
                gamma = 0.5*pi-beta+alpha;
                x_m = x_LR_i+sin(gamma)*R_c;
                y_m = y_top_vec(i_LR(i))+y_base(i_LR(i))-cos(gamma)*R_c;
                %plot(x_m,y_m,'k.','markersize',14)
                %x_circ = R_c*cos(0:0.1:2*pi);
                %y_circ = R_c*sin(0:0.1:2*pi);
                %plot(x_circ+x_m,y_circ+y_m,'-k')
                i_local = i_LR(i)+1;
                x_local = x_profile(i_local);
                y_new = []; % save y values

                while x_local < x_RL_i && x_local < x_profile(end)
                    y_new = [y_new, y_m + sqrt(R_c^2-(x_local-x_m)^2)-y_base(i_local)]; % new value for y_bot_vec

                    if y_new > y_top_vec(i_local) % no correcting filling, stop -> possibly go to next point (j)
                        y_new = [];
                        x_local = x_RL_i;
                        j = j -1;
                    else
                        i_local = i_local +1;
                        x_local = x_profile(i_local);
                    end

                end

                if length(y_new) >= 1
                    y_top_vec(i_LR(i)+1:i_local-1) = y_new;
                    idx_trig = i_RL(i_neigh(j));
                    x_RL_prev = x_RL_i;  % for next round: not trying to fill circles in range used earlier
                    trig = 1;

                    %plot(x_profile(i_LR(i)+1:i_local-1),y_new+y_base(i_LR(i)+1:i_local-1),'g.','markersize',12)
                end
            end
        end
    end


    % compute height difference
    y_profile = y_top_vec - y_bot_vec;
    idx_neg = find(y_profile<0); % find negative values; then fiber contact so zero 
    y_profile(idx_neg) = 0;

    figure(1), hold on
    plot(x_profile,y_top_vec+y_base,'--k','displayname','Smoothening')
    plt = plot(x_profile,y_bot_vec+y_base, '--k');
    set( get( get( plt, 'Annotation'), 'LegendInformation' ), 'IconDisplayStyle', 'off' );
end

%% figure options

figure(1)
legend('box','on','edgecolor','w','interpreter','latex','fontsize',10,'location','NorthWest','NumColumns',2)
xlabel('Width, x [$\mu$m]','interpreter','latex','fontsize',10)
ylabel('Height, y [$\mu$m]','interpreter','latex','fontsize',10)
set(gca,'fontsize',10)

% figure size 
width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([225 325 170 250])
axis equal
grid on
box on
