clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read and process friction data: show shear stress vs time for
% different rates on C/PEEK UD tape (385 degC, 15 kPa)

% Matlab version: R2021a


%% initialisation
mod_coeff = 0.90; %threshold for modulus fit, end; max difference local and average modulus
serie_range = [2 2 3 15]; % series, relates to unique label of specimens
series{1} = [6]; % meas nr within serie (relates to unique label of specimens)
series{2} = [1 2 3 4 5]; 
series{3} = [1 4];
series{4} = [8 14 16]; 

%% Go through the measurements

figure(1), clf(1), hold on

for serie_i = 1:length(serie_range) % go trhough series
    
    serie = serie_range(serie_i);
    range_meas = series{serie_i};
    
    for meas_i = 1:length(range_meas) % go through measurements within series

        meas = range_meas(meas_i);

        %% Load data
        cd ../FT_C-PEEK_15kPa_385degC        
        file_find = dir(['*_',num2str(serie),'-',num2str(meas),'.*']);
        file_name = file_find.name; 
                        
        if file_name(end-2:end) == 'txt'  % data logged on laptop (different format)
            data = readmatrix(file_name,'NumHeaderLines',1);
            fprintf(['File: ', file_find.name,'\n'])
            cd ../Scripts
            
            t = data(:,1); % time [s]
            d = data(:,6) - data(1,6);  % displacement [mm]
            force_corr = mean(data(end-200:end,5)); % end value (end of experiment)
            f_pull = data(:,5) - force_corr; % pull force, corrected for end value [N}   
            
        else    % data logged on friction tester PC (lower sampling rate)
            fid = fopen(file_name);
            C = textscan(fid,'%f');
            data = zeros(int32(length(C{1})/13),13);
            for i = 0:length(C{1})-1
                i_row = 1+floor(i/13);
                i_col = 1+mod(i,13);
                data(int32(i_row),int32(i_col)) = C{1}(i+1);
            end
            fprintf(['File: ', file_find.name,'\n'])
            fclose(fid);
            cd ../Scripts

            d = data(1,13) - data(:,13); % displacement [mm]
            force_corr = mean(data(end-5:end,6)); % end value (end of experiment)
            f_pull = data(:,6) - force_corr; % pull force, corrected for end value [N]
            t = data(:,2) - data(1,2); % time [s]
        end
        
        %% Analysis
        
        %% index start/end using displacement data, mean velocity, shear stress
        
        % velocity from file name
        name_u = find(file_find.name=='u');
        name_u_end = name_u + 1;
        while file_find.name(name_u_end) ~= '_'
            name_u_end = name_u_end + 1;
        end
        vel = str2double(file_find.name(name_u+1:name_u_end-1)); % velocity from file name

        % determine window for smoothening based on velocity form file name
        if file_name(end-2:end) == 'txt'  % data logged on laptop (higher sampling rate; larger window for smoothening)
            if vel <= 1
                window = 525; %1500
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 100;
            elseif vel <= 11
                window = 25;
            elseif vel <= 15
                window = 20;
            elseif vel <= 30
                window = 20;
            else
                window = 15;
            end
        else
            if vel <= 1
                window = 100;
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 50;
            elseif vel <= 8
                window = 25;
            elseif vel <= 15
                window = 15;
            else
                window = 15;
            end
        end
        
        % smoothening data
        d_filt = smoothdata(d,'gaussian',window); % filter data met moving median filter

        v_vec = [0]; % velocity vector
        a_vec = [0]; % acceleration vector
        for i = 2:length(t)-1
            dt = t(i+1) - t(i);
            v = (d_filt(i+1)-d_filt(i-1))/(2*dt);
            a = (d_filt(i+1)-2*d_filt(i)+d_filt(i-1))/(dt^2);
            v_vec(i) = v;
            a_vec(i) = a;
        end
        v_vec(length(t)) = v;
        a_vec(length(t)) = a;
        
        % determine global start and end 
        i_glob = 1; % global end range of start point
        while d(i_glob) < 1 % deformation below 1 mm
            i_glob = i_glob + 1;
        end
        
        i_glob_9 = i_glob; % global end range of start point, also global start range for end point
        while d(i_glob_9) < 9 % deformation around 9 mm
            i_glob_9 = i_glob_9 + 1;
        end
        
        i_glob_start = i_glob; % find around i_glob also global start range for start point
        while t(i_glob_start) > t(i_glob)-(2/vel*60)  % move 2 mm in time earlier based on velocity in experiment
            i_glob_start = i_glob_start - 1;
        end
                
        i_glob_end = i_glob;
        while t(i_glob_end) < t(i_glob) + d(end)/vel*60 % find index for time after full displacement
            i_glob_end = i_glob_end + 1;
        end           
                
        idx_start = find(a_vec(i_glob_start:i_glob)==max(a_vec(i_glob_start:i_glob)))+i_glob_start-1;
        idx_end = find(a_vec(i_glob_9:i_glob_end)==min(a_vec(i_glob_9:i_glob_end)))+i_glob_9-1;
        
        % shear stress
        tau = f_pull/2500/2*1e3; % [N/mm] -> MPa, times 1e3 results in [kPa] (division by 2, as 2 slip interfaces are present)      
           
        %% modulus fit
        
        [t,d,mod_i] = mod_fit_v1(idx_start,idx_end,t,d,tau,mod_coeff,window);
        
        %% Show data
        
        figure(1), hold on
        if serie_i == 2
            curves_store{meas_i} = [t(idx_start:idx_end) tau(idx_start:idx_end)];
        else
            plot(t(idx_start:idx_end),tau(idx_start:idx_end),'-k','linewidth',1,'displayname',[num2str(serie), '-', num2str(meas)]);
        end

    end
end

% compute mean curve with sample std               
% data range for mean curve
j_end = length(curves_store);
j_max = 1;
length_max = 1;

% find index with longest dataset
for j = 1:j_end
    if length(curves_store{j}) > length_max
        j_max = j;
        length_max = length(curves_store{j});
    end
end

% find start and end indices
t_base = curves_store{j_max}(:,1);
k_start = min(find(t_base>0));
k_end = min(find(t_base>10));
if isempty(k_end)
     k_end = length(t_base);
end

% determine mean curves
t_curve = zeros(1,k_end-k_start+1);
tau_curve = zeros(1,k_end-k_start+1);
k = k_start;
while k <= k_end
    t_k = t_base(k);
    t_curve(k-k_start+1) = t_k;

    % find clostes tau values; interpolation
    tau_k = zeros(1,j_end);
    idx_zero = []; % account for end of curves; no data
    for j = 1:j_end
        if j == j_max
            tau_k(j) = curves_store{j}(k,2);
        else
            idx_left = max(find(curves_store{j}(:,1)<t_k));
            idx_right = min(find(curves_store{j}(:,1)>t_k));
            if ~isempty(idx_right)

                % interpolation to find tau_k
                tau_L = curves_store{j}(idx_left,2); 
                tau_R = curves_store{j}(idx_right,2);
                t_L = curves_store{j}(idx_left,1);
                t_R = curves_store{j}(idx_right,1);
                tau_k(j) = tau_L + (tau_R-tau_L)*((t_k-t_L)/(t_R-t_L));
            else
                idx_zero = [idx_zero, j];
            end
        end
    end

    tau_k(idx_zero) = [];
    tau_curve(k-k_start+1) = mean(tau_k);
    k = k + 1;
end

plot(t_curve,tau_curve,'-k','linewidth',1.0);

xlabel('Time, t [s]','interpreter','Latex','fontsize',10)
ylabel('Shear stress, $\tau$ [kPa]','interpreter','Latex','fontsize',10)

text(2.1,3,'5 mm/min','interpreter','latex','fontsize',10,'color',[0.4 0.4 0.4])        
annotation('arrow',[0.35 0.35],[0.205 0.80],'color',[0.6 0.6 0.6],'Headwidth',6,'Headlength',6)
text(2,90,'125 mm/min','interpreter','latex','fontsize',10,'color',[0.4 0.4 0.4])
text(2.65,65,'$V$','interpreter','latex','fontsize',10,'color',[0.4 0.4 0.4])

set(gca,'fontsize',10)

width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([0 9.5 0 100])
grid on
box on

