clear all
clc
set(0,'defaultfigurecolor',[1 1 1])

%% INFO

% Read and process friction data: show shear stress relaxation with 
% time after sliding movement stopped for C/PEEK UD tape (385 degC, 15 kPa)

% Matlab version: R2021a


%% initialisation
rel_time = 28.5;  % time after sliding stopped, for relaxation curve

serie_range = [2 3 15 2]; % series, relates to unique label of specimens
series{1} = [8]; % meas nr within serie (relates to unique label of specimens)
series{2} = [11 5]; 
series{3} = [16]; 
series{4} = [9 11]; 

figure(1), clf(1)

%% Go through the measurements

i_color = 0;

for serie_i = 1:length(serie_range) % go through series
    
    serie = serie_range(serie_i);
    range_meas = series{serie_i};
    
    for meas_i = 1:length(range_meas) % go through measurements within serie

        meas = range_meas(meas_i);

        %% Load data
        cd ../FT_C-PEEK_15kPa_385degC  
        file_find = dir(['*_',num2str(serie),'-',num2str(meas),'.*']);
        file_name = file_find.name; 
                        
        if file_name(end-2:end) == 'txt'  % data logged on laptop (different format)
            data = readmatrix(file_name,'NumHeaderLines',1);
            fprintf(['File: ', file_find.name,'\n'])
            cd ../Scripts
            
            t = data(:,1); % time [s]
            d = data(:,6) - data(1,6);  % displacement [mm]
            force_corr = mean(data(end-200:end,5)); % end value (end of experiment)
            f_pull = data(:,5) - force_corr; % pull force, corrected for end value [N}    
            
        else    % data logged on friction tester PC (lower sampling rate)
            fid = fopen(file_name);
            C = textscan(fid,'%f');
            data = zeros(int32(length(C{1})/13),13);
            for i = 0:length(C{1})-1
                i_row = 1+floor(i/13);
                i_col = 1+mod(i,13);
                data(int32(i_row),int32(i_col)) = C{1}(i+1);
            end
            fprintf(['File: ', file_find.name,'\n'])
            fclose(fid);
            cd ../Scripts

            d = data(1,13) - data(:,13); % displacement [mm]
            force_corr = mean(data(end-5:end,6)); % end value (end of experiment)
            f_pull = data(:,6) - force_corr; % pull force, corrected for end value [N]
            t = data(:,2) - data(1,2); % time [s]
        end
        
        %% Analysis
        
        %% index start/end using displacement data, mean velocity, shear stress
        
        % velocity from file name
        name_u = find(file_find.name=='u');
        name_u_end = name_u + 1;
        while file_find.name(name_u_end) ~= '_'
            name_u_end = name_u_end + 1;
        end
        vel = str2double(file_find.name(name_u+1:name_u_end-1)); % velocity from file name

        % determine window for smoothening based on velocity form file name
        if file_name(end-2:end) == 'txt'  % data logged on laptop (higher sampling rate; larger window for smoothening)
            if vel <= 1
                window = 525; %1500
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 100;
            elseif vel <= 11
                window = 25;
            elseif vel <= 15
                window = 20;
            elseif vel <= 30
                window = 20;
            else
                window = 15;
            end
        else
            if vel <= 1
                window = 100;
            elseif vel <= 3
                window = 75;
            elseif vel <= 5
                window = 50;
            elseif vel <= 8
                window = 25;
            elseif vel <= 15
                window = 15;
            else
                window = 15;
            end
        end
        
        % smoothening data
        d_filt = smoothdata(d,'gaussian',window); % filter data met moving median filter
        v_vec = [0]; % velocity vector
        a_vec = [0]; % acceleration vector
        for i = 2:length(t)-1
            dt = t(i+1) - t(i);
            v = (d_filt(i+1)-d_filt(i-1))/(2*dt);
            a = (d_filt(i+1)-2*d_filt(i)+d_filt(i-1))/(dt^2);
            v_vec(i) = v;
            a_vec(i) = a;
        end
        v_vec(length(t)) = v;
        a_vec(length(t)) = a;
        
        % determine global start and end 
        i_glob = 1; % global end range of start point
        while d(i_glob) < 1 % deformation below 1 mm
            i_glob = i_glob + 1;
        end
        
        i_glob_9 = i_glob; % global end range of start point, also global start range for end point
        while d(i_glob_9) < 9 % deformation around 9 mm
            i_glob_9 = i_glob_9 + 1;
        end
        
        i_glob_start = i_glob; % find around i_glob also global start range for start point
        while t(i_glob_start) > t(i_glob)-(2/vel*60)  % move 2 mm in time earlier based on velocity in experiment
            i_glob_start = i_glob_start - 1;
        end
                
        i_glob_end = i_glob;
        while t(i_glob_end) < t(i_glob) + d(end)/vel*60 % find index for time after full displacement
            i_glob_end = i_glob_end + 1;
        end           
                
        idx_start = find(a_vec(i_glob_start:i_glob)==max(a_vec(i_glob_start:i_glob)))+i_glob_start-1;
        idx_end = find(a_vec(i_glob_9:i_glob_end)==min(a_vec(i_glob_9:i_glob_end)))+i_glob_9-1;
        
        % shear stress
        tau = f_pull/2500/2*1e3; % [N/mm] -> MPa, times 1e3 results in [kPa] (division by 2, as 2 slip interfaces are present)      
                
        %% Relaxation
        
        % start and end indices
        idx_f_rel_start = idx_end - 10;
        idx_f_rel_end = idx_end + 10;
        
        % determine derivative to identify start of relaxation (drop in
        % shear stress)
        dtau_dt_sec_vec = [];
        for i_rel = idx_f_rel_start:idx_f_rel_end
            dt = mean([t(i_rel+1)-t(i_rel),t(i_rel)-t(i_rel-1)]);
            dtau_dt_sec = (tau(i_rel+1)-2*tau(i_rel)+tau(i_rel-1))/(dt^2);
            dtau_dt_sec_vec = [dtau_dt_sec_vec, dtau_dt_sec];
        end
        
        idx_rel_start = find(dtau_dt_sec_vec==min(dtau_dt_sec_vec))+idx_f_rel_start-2; % minus 1: to obtain correct pos, extra minus 1: to start before actual sharp decrease
        
        % find end of relaxation
        idx_rel_end = idx_rel_start;
        while t(idx_rel_end) < t(idx_rel_start)+rel_time   % relaxation time
            idx_rel_end = idx_rel_end + 1;
        end
        
        %% Show data

        figure(1), hold on
        plot(t(idx_rel_start:end)-t(idx_rel_start),tau(idx_rel_start:end),'-','linewidth',2.0,'color',[0.1 0.1 0.1]+0.15*i_color,'displayname',[num2str(vel), ' mm/min'])
        i_color = i_color +1;
    end
end

figure(1)
legend('interpreter','latex','fontsize',10,'box','off')
xlabel('Relaxation time, t [s]','interpreter','latex','fontsize',10)
ylabel('Shear stress, $\tau$ [kPa]','interpreter','latex','fontsize',10)
set(gca,'fontsize',10)
box on
grid on

% figure size 
width = 9; % single column: 9 cm, 1.5 column: 14 cm, double column: 19 cm
set(gcf,'units','centimeters','position',[5,5,width,0.75*width])
axis([0 15 0 40])
grid on
box on
